#
# spec file for package golang-github-prometheus-node_exporter
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2017 Silvio Moioli <moio@suse.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{go_nostrip}

Name:           golang-github-prometheus-node_exporter
Version:        0.18.1
Release:        lp152.3.3.1
Summary:        Prometheus exporter for machine metrics
License:        Apache-2.0
Group:          System/Management
Url:            https://prometheus.io/
Source:         node_exporter-v%{version}.tar.xz
Source1:        prometheus-node_exporter.service
Source2:        README
Source3:        update-tarball.sh
BuildRequires:  fdupes
BuildRequires:  go1.11
BuildRequires:  golang-packaging
BuildRequires:  xz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{?systemd_requires}
Requires(pre):  shadow
%{go_provides}
Provides:       node_exporter
Provides:       prometheus(node_exporter)

%description
Prometheus exporter for hardware and OS metrics exposed by *NIX kernels, written in Go with pluggable metric collectors.

%prep
%setup -q -n node_exporter

%build
make collector/fixtures/sys/.unpacked  # unpacks text fixtures required by gotest
%goprep github.com/prometheus/node_exporter
%gobuild -mod=vendor ""

%install
%goinstall
%gosrc
install -D -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/prometheus-node_exporter.service
install -Dd -m 0755 %{buildroot}%{_sbindir}
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rcprometheus-node_exporter
%gofilelist
%fdupes %{buildroot}

%check
%gotest github.com/prometheus/node_exporter -mod=vendor

%pre
%service_add_pre prometheus-node_exporter.service
getent group prometheus >/dev/null || %{_sbindir}/groupadd -r prometheus
getent passwd prometheus >/dev/null || %{_sbindir}/useradd -r -g prometheus -d %{_localstatedir}/lib/prometheus -M -s /sbin/nologin prometheus

%post
%service_add_post prometheus-node_exporter.service

%preun
%service_del_preun prometheus-node_exporter.service

%postun
%service_del_postun prometheus-node_exporter.service

%files -f file.lst
%defattr(-,root,root,-)
%doc README.md
%license LICENSE
%{_bindir}/node_exporter
%{_unitdir}/prometheus-node_exporter.service
%{_sbindir}/rcprometheus-node_exporter

%changelog
* Thu Aug 15 2019 Michael Ströder <michael@stroeder.com>
- Update to 0.18.1
  0.18.1 / 2019-06-04
  Changes
  * [BUGFIX] Fix incorrect sysctl call in BSD meminfo collector, resulting in broken swap metrics on FreeBSD #1345
  * [BUGFIX] Fix rollover bug in mountstats collector #1364
  0.18.0 / 2019-05-09
  Breaking changes
  * Renamed interface label to device in netclass collector for consistency with
  * other network metrics #1224
  * The cpufreq metrics now separate the cpufreq and scaling data based on what the driver provides. #1248
  * The labels for the network_up metric have changed, see issue #1236
  * Bonding collector now uses mii_status instead of operstatus #1124
  * Several systemd metrics have been turned off by default to improve performance #1254
  * These include unit_tasks_current, unit_tasks_max, service_restart_total, and unit_start_time_seconds
  * The systemd collector blacklist now includes automount, device, mount, and slice units by default. #1255
  Changes
  * [CHANGE] Bonding state uses mii_status #1124
  * [CHANGE] Add a limit to the number of in-flight requests #1166
  * [CHANGE] Renamed interface label to device in netclass collector #1224
  * [CHANGE] Add separate cpufreq and scaling metrics #1248
  * [CHANGE] Several systemd metrics have been turned off by default to improve performance #1254
  * [CHANGE] Expand systemd collector blacklist #1255
  * [CHANGE] Split cpufreq metrics into a separate collector #1253
  * [FEATURE] Add a flag to disable exporter metrics #1148
  * [FEATURE] Add kstat-based Solaris metrics for boottime, cpu and zfs collectors #1197
  * [FEATURE] Add uname collector for FreeBSD #1239
  * [FEATURE] Add diskstats collector for OpenBSD #1250
  * [FEATURE] Add pressure collector exposing pressure stall information for Linux #1174
  * [FEATURE] Add perf exporter for Linux #1274
  * [ENHANCEMENT] Add Infiniband counters #1120
  * [ENHANCEMENT] Add TCPSynRetrans to netstat default filter #1143
  * [ENHANCEMENT] Move network_up labels into new metric network_info #1236
  * [ENHANCEMENT] Use 64-bit counters for Darwin netstat
  * [BUGFIX] Add fallback for missing /proc/1/mounts #1172
  * [BUGFIX] Fix node_textfile_mtime_seconds to work properly on symlinks #1326
* Fri Aug  2 2019 Jan Fajerski <jan.fajerski@suse.com>
- Add network-online (Wants and After) dependency to systemd unit bsc#1143913
* Tue Dec 11 2018 Jan Fajerski <jan.fajerski@suse.com>
- Update to 0.17.0
  + includes breaking changes
  + supvervisord collector reports start_time_seconds rather than uptime
  + The wifi collector is disabled by default due to suspected caching issues and goroutine leaks
  See https://github.com/prometheus/node_exporter/releases/tag/v0.17.0
  for full changelog
* Thu Nov 29 2018 Jan Fajerski <jan.fajerski@suse.com>
- Update to 0.16.0
  + includes breaking changes
  + several metrics renamed
  + split out cpu guest metrics
  See https://github.com/prometheus/node_exporter/releases/tag/v0.16.0
  for full changelog
* Sun Feb 18 2018 marix@marix.org
- Run tests during packaging
* Thu Jan 25 2018 kkaempf@suse.com
- Update to 0.15.2
  See https://github.com/prometheus/node_exporter/blob/master/CHANGELOG.md
- Provides node_exporter, prometheus(node_exporter)
* Thu Jul 27 2017 tserong@suse.com
- Add BuildRequires: fdupes
* Tue May  9 2017 tserong@suse.com
- Add systemd unit file
- Run as unprivileged "prometheus" user
* Wed Mar 29 2017 moio@suse.com
- Initial version
